# About

ScippNeutron builds on top of Scipp and provides features specific to handling and reducing data generated in neutron scattering facilities.
A key example is "unit conversion", e.g., from time-of-flight to energy transfer in an inelastic neutron scattering experiment at a spallation-based neutron source.

## Development

ScippNeutron is an open source project by the [European Spallation Source ERIC](https://europeanspallationsource.se/) (ESS).
Other major contributions were provided by the [Science and Technology Facilities Council](https://www.ukri.org/councils/stfc/) (STFC).

## License

ScippNeutron is available as open source under the [BSD-3 license](https://opensource.org/licenses/BSD-3-Clause).

## Citing ScippNeutron

Please cite the following:

[![DOI](https://zenodo.org/badge/305999676.svg)](https://zenodo.org/doi/10.5281/zenodo.7447231)

To cite a specific version of ScippNeutron, select the desired version on Zenodo to get the corresponding DOI.

## Older versions of the documentation

Older versions of the documentation pages can be found under the assets of each [release](https://github.com/scipp/scippneutron/releases).
Simply download the archive, unzip and view locally in a web browser.

## Source code and development

ScippNeutron is hosted and developed [on GitHub](https://github.com/scipp/scippneutron).

```{toctree}
---
hidden:
---

bibliography
```
